<?PHP
//
// ZendTo
// Copyright (C) 2006 Jeffrey Frey, frey at udel dot edu
// Copyright (C) 2020 Julian Field, Jules at ZendTo dot com 
//
// Based on the original PERL dropbox written by Doke Scott.
// Developed by Julian Field.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//

//
// Include the dropbox preferences -- we need this to have the
// dropbox filepaths setup for us, beyond simply needing our
// configuration!
//
require "../config/preferences.php";
require_once(NSSDROPBOX_LIB_DIR."Smartyconf.php");
require_once(NSSDROPBOX_LIB_DIR."NSSDropoff.php");

if ( $theDropbox = new NSSDropbox($NSSDROPBOX_PREFS) ) {
  //
  // This page handles the listing of an authenticated user's 
  // dropoffs.  If the user is NOT authenticated, then an error
  // is presented.
  //

  $theDropbox->SetupPage();

  if ( $theDropbox->authorizedUser() ) {
    //
    // Returns an array of all NSSDropoff instances belonging to
    // this user.
    //
    $allDropoffs = NSSDropoff::dropoffsForCurrentUser($theDropbox);
    $allRequests = Req::requestsFromCurrentUser($theDropbox);
    //
    // Start the web page and add some Javascript to automatically
    // fill-in and submit a pickup form when a dropoff on the page
    // is clicked.
    //
    $dMax = is_array($allDropoffs)?count($allDropoffs):0;
    $rMax = is_array($allRequests)?count($allRequests):0;
    $iMax = $dMax + $rMax;
    $smarty->assign('countDropoffs', $iMax); // Used to decide if to show table at all
    $totalsize = 0;
    
    if ( ($allDropoffs || $allRequests) && $iMax>0 ) {
      $outputDropoffs = array();
      foreach($allDropoffs as $dropoff) {
        $od = array();
        $od['claimID'] = $dropoff->claimID();
        $od['senderName'] = $dropoff->senderName();
        $od['senderEmail'] = $dropoff->senderEmail();
        $od['senderOrg']  = htmlspecialchars($dropoff->senderOrganization());
        $od['subject'] = htmlentities($dropoff->subject(), ENT_QUOTES, 'UTF-8');

        $created = timeForDate($dropoff->created());
        $expires = $created + $dropoff->lifeseconds();
        $od['createdDate'] = $created;
        $od['expiresDate'] = $expires;
        $od['formattedBytes'] = $dropoff->formattedBytes();
        $od['isEncrypted'] = $dropoff->isEncrypted();
        $od['numPickups'] = $dropoff->numPickups();

        $b = $dropoff->bytes();
        $od['Bytes'] = $b;
        $totalsize += $b;

        // HTML output wants to include recipients
        $recilist = array();
        foreach ($dropoff->recipients() as $r) {
          if (empty($r[0])) {
            $ea = '<' . $r[1] . '>';
          } else {
            $ea = $r[0] . ' <' . $r[1] . '>';
          }
          $recilist[] = htmlentities($ea, ENT_NOQUOTES, 'UTF-8');
        }
        $od['recipients'] = implode('<br/>', $recilist);

        $outputDropoffs[] = $od;
      }

      foreach($allRequests as $request) {
        $od = array();
        $od['claimID']     = str_replace(' ', '&nbsp;', $request->words());
        $od['senderName']  = $request->senderName();
        $od['senderEmail'] = $request->senderEmail();
        $od['senderOrg']   = $request->senderOrg();
        $od['subject']     = htmlentities($request->subject(), ENT_QUOTES, 'UTF-8');
        $od['createdDate'] = $request->createdTime();
        $od['expiresDate'] = $request->expiryTime();
        $od['formattedBytes'] = gettext('Request');
        $od['isEncrypted'] = $request->encrypted();
        $od['numPickups']  = 0;
        $od['Bytes']       = 0;
        $r = '<' . $request->recipEmail() . '>';
        if (!empty($request->recipName()))
          $r = $request->recipName() . ' ' . $r;
        $od['recipients'] = htmlentities($r, ENT_NOQUOTES, 'UTF-8');

        $outputDropoffs[] = $od;
      }
      $smarty->assignByRef('dropoffs', $outputDropoffs);
      $smarty->assign('formattedTotalBytes', NSSFormattedMemSize($totalsize));
    }
  } else {
    NSSError(gettext("This feature is only available to users who have logged in."), gettext("Access Denied"));
  }

  $smarty->display('pickup_list.tpl');
}

?>
